\name{zsum.test}
\alias{zsum.test}
\title{
z test for summary data}
\description{
This function is based on the standard normal distribution and 
creates confidence intervals and tests hypotheses for both one 
and two sample problems based on summarized information the user 
passes to the function. Output is identical to that produced with 
\code{z.test}.
}
\usage{
zsum.test(mean.x, sigma.x = NULL, n.x = NULL, mean.y = NULL, sigma.y = NULL, n.y = NULL, alternative = "two.sided", mu = 0, conf.level = 0.95)
}
\arguments{
  \item{mean.x}{The mean of the first sample}
  \item{sigma.x}{The estimated standard deviation of the first population}
  \item{n.x}{The number of observations in the first sample}
  \item{mean.y}{The mean of the second sample}
  \item{sigma.y}{The estimated standard deviation of the second population}
  \item{n.y}{The number of observations in the first sample}
  \item{alternative}{a character string, one of \code{"greater"}, \code{"less"}
or \code{"two.sided"}, or the initial letter of each, indicating the specification of the alternative hypothesis. For one-sample tests, \code{alternative} refers to the true mean of the parent population in relation to the hypothesized
value \code{mu}. For the standard two-sample tests, \code{alternative} refers to the difference 
between the true population mean for \code{x} and that for \code{y}, in relation to \code{mu}.}
  \item{mu}{a single number representing the value of the mean or difference in means  specified by the null hypothesis}
  \item{conf.level}{confidence level for the returned confidence interval, restricted to lie between zero and one}
}
\details{
If \code{y} is \code{NULL} , a one-sample z-test is carried out with \code{x} .
If y is not \code{NULL}, a standard two-sample z-test is performed. 
}
\value{
A list of class \code{htest}, containing the following components: 
\item{\code{statistic} }{the z-statistic, with names attribute \code{z}.}
\item{\code{p.value} }{the p-value for the test}
\item{\code{conf.int } }{is a confidence interval (vector of length 2) for the true mean or difference in means. The confidence level is recorded in the attribute \code{conf.level}. When alternative is not \code{"two.sided"}, the confidence interval will be half-infinite, 
to reflect the interpretation of a confidence interval as the set of all values \code{k} for which one would not reject the null hypothesis that 
the true mean or difference in means is \code{k}. Here, infinity will be represented by \code{Inf}.}
\item{\code{estimate} }{vector of length 1 or 2, giving the sample mean(s) or mean of differences; these estimate the corresponding population 
parameters. Component \code{estimate} has a names attribute describing its elements.}
\item{\code{null.value} }{}
\item{\code{alternative} }{records the value of the input argument alternative: 
\code{"greater"} , \code{"less"} or \code{"two.sided"}. }
\item{\code{data.name} }{a character string (vector of length 1) containing the names \code{x} and \code{y} for the two summarized samples}
}
\references{
Kitchens, L. J. (2003). \emph{Basic Statistics and Data Analysis}. Duxbury.

Hogg, R. V. and Craig, A. T. (1970). \emph{Introduction to Mathematical Statistics, 3rd ed}. Toronto, Canada: Macmillan. 

Mood, A. M., Graybill, F. A. and Boes, D. C. (1974). \emph{Introduction to the Theory of Statistics, 3rd ed}. New York: McGraw-Hill. 

Snedecor, G. W. and Cochran, W. G. (1980). \emph{Statistical Methods, 7th ed}. Ames, Iowa: Iowa State University Press.
}
\author{
Alan T. Arnholt}
\note{
This function was obtained from another package.
}
\section{Null Hypothesis}{For the one-sample z-test, the null hypothesis is that the mean of the population from which \code{x} is drawn is \code{mu}. For the standard two-sample z-tests, the null hypothesis is that the population mean for \code{x} less that for \code{y} is \code{mu}.

The alternative hypothesis in each case indicates the direction of divergence of the population mean for \code{x} (or difference of means of \code{x} and \code{y})
from \code{mu} (i.e., \code{"greater"} , \code{"less"}, \code{"two.sided"} ).}

\section{Test Assumptions}{The assumption of normality for the underlying distribution or a sufficiently 
large sample size is required along with the population standard deviation to use Z procedures.}

\section{Confidence Intervals}{For each of the above tests, an expression for the 
related confidence interval (returned component \code{conf.int}) can be obtained in the usual way by inverting the expression for the test statistic. Note that, as explained 
under the description of \code{conf.int}, the confidence interval will be half-infinite when 
alternative is not \code{"two.sided"}; infinity will be represented by \code{Inf}.}

\seealso{
\code{\link{z.test}} for raw data, and \code{\link{tsum.test}} for the corresponding test using the t-distribution
}
\examples{
##See Chapter 8 of  the manual.
}
\keyword{htest}